import pytest
import unittest

IPython = pytest.importorskip("IPython")

from PyFoam.Applications.IPythonNotebook import IPythonNotebook
